@@ -16,7 +16,7 @@ use Wikibase::Datatype::Value::Item;
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 sub obj2struct {
 	my ($obj, $base_uri) = @_;
@@ -42,6 +42,11 @@ sub obj2struct {
 			Wikibase::Datatype::Struct::Form::obj2struct($form, $base_uri);
 	}
 
+	# Id.
+	if (defined $obj->id) {
+		$struct_hr->{'id'} = $obj->id;
+	}
+
 	# Last revision id.
 	if (defined $obj->lastrevid) {
 		$struct_hr->{'lastrevid'} = $obj->lastrevid;
@@ -49,7 +54,7 @@ sub obj2struct {
 
 	# Language.
 	if (defined $obj->language) {
-		$struct_hr->{'language'} = $obj->language->value;
+		$struct_hr->{'language'} = $obj->language;
 	}
 
 	# Lemmas.
@@ -60,7 +65,7 @@ sub obj2struct {
 
 	# Lexical category.
 	if (defined $obj->lexical_category) {
-		$struct_hr->{'lexicalCategory'} = $obj->lexical_category->value;
+		$struct_hr->{'lexicalCategory'} = $obj->lexical_category;
 	}
 
 	# Modified date.
@@ -73,6 +78,11 @@ sub obj2struct {
 		$struct_hr->{'ns'} = $obj->ns;
 	}
 
+	# Page id.
+	if (defined $obj->page_id) {
+		$struct_hr->{'pageid'} = $obj->page_id;
+	}
+
 	# Senses.
 	foreach my $sense (@{$obj->senses}) {
 		$struct_hr->{'senses'} //= [];
@@ -102,19 +112,24 @@ sub struct2obj {
 		err "Structure isn't for 'lexeme' type.";
 	}
 
-	# Grammatical features.
-	my $gm_ar = [];
-	foreach my $gm (@{$struct_hr->{'grammaticalFeatures'}}) {
-		push @{$gm_ar}, Wikibase::Datatype::Value::Item->new(
-			'value' => $gm,
+	# Forms.
+	my $forms_ar = [];
+	foreach my $form_hr (@{$struct_hr->{'forms'}}) {
+		push @{$forms_ar}, Wikibase::Datatype::Struct::Form::struct2obj($form_hr);
+	}
+
+	# Lemmas.
+	my $lemmas_ar = [];
+	foreach my $lang (keys %{$struct_hr->{'lemmas'}}) {
+		push @{$lemmas_ar}, Wikibase::Datatype::Struct::Language::struct2obj(
+			$struct_hr->{'lemmas'}->{$lang},
 		);
 	}
 
-	# Representations.
-	my $representations_ar;
-	foreach my $lang (keys %{$struct_hr->{'representations'}}) {
-		push @{$representations_ar}, Wikibase::Datatype::Struct::Language::struct2obj(
-			$struct_hr->{'representations'}->{$lang});
+	# Senses.
+	my $senses_ar = [];
+	foreach my $sense_hr (@{$struct_hr->{'senses'}}) {
+		push @{$senses_ar}, Wikibase::Datatype::Struct::Sense::struct2obj($sense_hr);
 	}
 
 	# Statements.
@@ -128,10 +143,18 @@ sub struct2obj {
 	}
 
 	my $obj = Wikibase::Datatype::Lexeme->new(
-		'grammatical_features' => $gm_ar,
+		'forms' => $forms_ar,
 		'id' => $struct_hr->{'id'},
-		'representations' => $representations_ar,
+		'language' => $struct_hr->{'language'},
+		defined $struct_hr->{'lastrevid'} ? ('lastrevid' => $struct_hr->{'lastrevid'}) : (),
+		'lemmas' => $lemmas_ar,
+		defined $struct_hr->{'lexicalCategory'} ? ('lexical_category' => $struct_hr->{'lexicalCategory'}) : (),
+		defined $struct_hr->{'modified'} ? ('modified' => $struct_hr->{'modified'}) : (),
+		defined $struct_hr->{'ns'} ? ('ns' => $struct_hr->{'ns'}) : (),
+		defined $struct_hr->{'pageid'} ? ('page_id' => $struct_hr->{'pageid'}) : (),
+		'senses' => $senses_ar,
 		'statements' => $statements_ar,
+		defined $struct_hr->{'title'} ? ('title' => $struct_hr->{'title'}) : (),
 	);
 
 	return $obj;
@@ -385,45 +408,166 @@ Returns Wikibase::Datatype::Lexeme instance.
  use warnings;
 
  use Data::Printer;
+ use Unicode::UTF8 qw(decode_utf8);
  use Wikibase::Datatype::Struct::Lexeme qw(struct2obj);
 
  # Lexeme structure.
  my $struct_hr = {
-         'grammaticalFeatures' => [
-                 'Q163012',
-                 'Q163014',
-         ],
-         'representations' => {
-                 'cs' => {
-                         'language' => 'cs',
-                         'value' => 'Representation cs',
-                 },
-                 'en' => {
-                         'language' => 'en',
-                         'value' => 'Representation en',
-                 },
-         },
          'claims' => {
-                 'P31' => [{
+                 'P5185' => [{
                          'mainsnak' => {
-                                 'datatype' => 'wikibase-item',
                                  'datavalue' => {
                                          'type' => 'wikibase-entityid',
                                          'value' => {
                                                  'entity-type' => 'item',
-                                                 'id' => 'Q5',
-                                                 'numeric-id' => 5,
+                                                 'id' => 'Q499327',
+                                                 'numeric-id' => 499327,
                                          },
                                  },
-                                 'property' => 'P31',
+                                 'datatype' => 'wikibase-item',
+                                 'property' => 'P5185',
                                  'snaktype' => 'value',
                          },
                          'rank' => 'normal',
+                         'references' => [{
+                                 'snaks' => {
+                                         'P214' => [{
+                                                 'datavalue' => {
+                                                         'type' => 'string',
+                                                         'value' => '113230702',
+                                                 },
+                                                 'datatype' => 'external-id',
+                                                 'property' => 'P214',
+                                                 'snaktype' => 'value',
+                                         }],
+                                         'P248' => [{
+                                                 'datavalue' => {
+                                                         'type' => 'wikibase-entityid',
+                                                         'value' => {
+                                                                 'entity-type' => 'item',
+                                                                 'id' => 'Q53919',
+                                                                 'numeric-id' => 53919,
+                                                         },
+                                                 },
+                                                 'datatype' => 'wikibase-item',
+                                                 'property' => 'P248',
+                                                 'snaktype' => 'value',
+                                         }],
+                                         'P813' => [{
+                                                 'datavalue' => {
+                                                         'type' => 'time',
+                                                         'value' => {
+                                                                 'after' => 0,
+                                                                 'before' => 0,
+                                                                 'calendarmodel' => 'http://test.wikidata.org/entity/Q1985727',
+                                                                 'precision' => 11,
+                                                                 'time' => '+2013-12-07T00:00:00Z',
+                                                                 'timezone' => 0,
+                                                         },
+                                                 },
+                                                 'datatype' => 'time',
+                                                 'property' => 'P813',
+                                                 'snaktype' => 'value',
+                                         }],
+                                 },
+                                 'snaks-order' => [
+                                         'P248',
+                                         'P214',
+                                         'P813',
+                                 ],
+                         }],
                          'type' => 'statement',
                  }],
          },
+         'forms' => [{
+                 'claims' => {
+                         'P898' => [{
+                                 'mainsnak' => {
+                                         'datavalue' => {
+                                                 'type' => 'string',
+                                                 'value' => decode_utf8('pɛs'),
+                                         },
+                                         'datatype' => 'string',
+                                         'property' => 'P898',
+                                         'snaktype' => 'value',
+                                 },
+                                 'rank' => 'normal',
+                                 'type' => 'statement',
+                         }],
+                 },
+                 'grammaticalFeatures' => [
+                         'Q110786',
+                         'Q131105',
+                 ],
+                 'id' => 'L469-F1',
+                 'representations' => {
+                         'cs' => {
+                                 'language' => 'cs',
+                                 'value' => 'pes',
+                         },
+                 },
+         }],
+         'id' => 'L469',
+         'language' => 'Q9056',
+         'lastrevid' => 1428556087,
+         'lemmas' => {
+                 'cs' => {
+                         'language' => 'cs',
+                         'value' => 'pes',
+                 },
+         },
+         'lexicalCategory' => 'Q1084',
+         'modified' => '2022-06-24T12:42:10Z',
+         'ns' => 146,
+         'pageid' => 54393954,
+         'senses' => [{
+                 'claims' => {
+                         'P18' => [{
+                                 'mainsnak' => {
+                                         'datavalue' => {
+                                                 'type' => 'string',
+                                                 'value' => 'Canadian Inuit Dog.jpg',
+                                         },
+                                         'datatype' => 'commonsMedia',
+                                         'property' => 'P18',
+                                         'snaktype' => 'value',
+                                 },
+                                 'rank' => 'normal',
+                                 'type' => 'statement',
+                         }],
+                         'P5137' => [{
+                                 'mainsnak' => {
+                                         'datavalue' => {
+                                                 'type' => 'wikibase-entityid',
+                                                 'value' => {
+                                                         'entity-type' => 'item',
+                                                         'id' => 'Q144',
+                                                         'numeric-id' => 144,
+                                                 },
+                                         },
+                                         'datatype' => 'wikibase-item',
+                                         'property' => 'P5137',
+                                         'snaktype' => 'value',
+                                 },
+                                 'rank' => 'normal',
+                                 'type' => 'statement',
+                         }],
+                 },
+                 'glosses' => {
+                         'cs' => {
+                                 'language' => 'cs',
+                                 'value' => decode_utf8('psovitá šelma chovaná jako domácí zvíře'),
+                         },
+                         'en' => {
+                                 'language' => 'en',
+                                 'value' => 'domesticated mammal related to the wolf',
+                         },
+                 },
+                 'id' => 'L469-S1',
+         }],
+         'title' => 'Lexeme:L469',
          'type' => 'lexeme',
- };
+  };
 
  # Get object.
  my $obj = struct2obj($struct_hr);
@@ -433,22 +577,37 @@ Returns Wikibase::Datatype::Lexeme instance.
 
  # Output:
  # Wikibase::Datatype::Lexeme  {
- #     Parents       Mo::Object
- #     public methods (8) : BUILD, can (UNIVERSAL), DOES (UNIVERSAL), err (Error::Pure), check_array_object (Mo::utils), check_entity (Wikibase::Datatype::Utils), isa (UNIVERSAL), VERSION (UNIVERSAL)
- #     private methods (1) : __ANON__ (Mo::is)
+ #     parents: Mo::Object
+ #     public methods (5):
+ #         BUILD
+ #         Error::Pure:
+ #             err
+ #         Mo::utils:
+ #             check_array_object, check_number
+ #         Wikibase::Datatype::Utils:
+ #             check_entity
+ #     private methods (0)
  #     internals: {
- #         grammatical_features   [
- #             [0] Wikibase::Datatype::Value::Item,
- #             [1] Wikibase::Datatype::Value::Item
+ #         forms              [
+ #             [0] Wikibase::Datatype::Form
  #         ],
- #         id                     undef,
- #         representations        [
- #             [0] Wikibase::Datatype::Value::Monolingual,
- #             [1] Wikibase::Datatype::Value::Monolingual
+ #         id                 "L469",
+ #         language           "Q9056",
+ #         lastrevid          1428556087,
+ #         lemmas             [
+ #             [0] Wikibase::Datatype::Value::Monolingual
  #         ],
- #         statements             [
+ #         lexical_category   "Q1084",
+ #         modified           "2022-06-24T12:42:10Z" (dualvar: 2022),
+ #         ns                 146,
+ #         page_id            54393954,
+ #         senses             [
+ #             [0] Wikibase::Datatype::Sense
+ #         ],
+ #         statements         [
  #             [0] Wikibase::Datatype::Statement
- #         ]
+ #         ],
+ #         title              "Lexeme:L469"
  #     }
  # }
 
@@ -495,12 +654,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2020-2021
+© 2020-2022 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
