@@ -11,7 +11,7 @@ use Wikibase::Datatype::Value::Globecoordinate;
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 sub obj2struct {
 	my ($obj, $base_uri) = @_;
@@ -106,7 +106,7 @@ Returns reference to hash with structure.
 
  my $obj = struct2obj($struct_hr);
 
-Convert structure of item to object.
+Convert structure of globe coordinate to object.
 
 Returns Wikibase::Datatype::Value::Globecoordinate instance.
 
@@ -242,12 +242,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2020-2021
+© 2020-2022 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
