@@ -11,7 +11,7 @@ use Wikibase::Datatype::Value::Quantity;
 
 Readonly::Array our @EXPORT_OK => qw(obj2struct struct2obj);
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 sub obj2struct {
 	my ($obj, $base_uri) = @_;
@@ -32,7 +32,7 @@ sub obj2struct {
 	if (defined $obj->unit) {
 		$unit = $base_uri.$obj->unit;
 	} else {
-		$unit = 1;
+		$unit = '1';
 	}
 	my $struct_hr = {
 		'value' => {
@@ -261,12 +261,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© Michal Josef Špaček 2020-2021
+© 2020-2022 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
